.. gfort2py documentation master file, created by
   sphinx-quickstart on Mon Apr 27 15:58:34 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to gfort2py's documentation!
====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   
   usage
   testsuite
   fortranabi


